@@ -2,13 +2,17 @@
 # Copyright (c) 2022 Airbyte, Inc., all rights reserved.
 #
 
+import json
+import logging
 from dataclasses import InitVar, dataclass, field
 from typing import Any, Iterable, List, Mapping, MutableMapping, Optional, Union
 
 import requests
-from airbyte_cdk.models import SyncMode
+from airbyte_cdk.models import AirbyteLogMessage, AirbyteMessage, Level, SyncMode
+from airbyte_cdk.models import Type as MessageType
 from airbyte_cdk.sources.declarative.exceptions import ReadException
 from airbyte_cdk.sources.declarative.extractors.http_selector import HttpSelector
+from airbyte_cdk.sources.declarative.interpolation import InterpolatedString
 from airbyte_cdk.sources.declarative.requesters.error_handlers.response_action import ResponseAction
 from airbyte_cdk.sources.declarative.requesters.paginators.no_pagination import NoPagination
 from airbyte_cdk.sources.declarative.requesters.paginators.paginator import Paginator
@@ -16,8 +20,10 @@ from airbyte_cdk.sources.declarative.requesters.requester import Requester
 from airbyte_cdk.sources.declarative.retrievers.retriever import Retriever
 from airbyte_cdk.sources.declarative.stream_slicers.single_slice import SingleSlice
 from airbyte_cdk.sources.declarative.stream_slicers.stream_slicer import StreamSlicer
-from airbyte_cdk.sources.declarative.types import Record, StreamSlice, StreamState
+from airbyte_cdk.sources.declarative.types import Config, Record, StreamSlice, StreamState
+from airbyte_cdk.sources.streams.core import StreamData
 from airbyte_cdk.sources.streams.http import HttpStream
+from airbyte_cdk.utils.airbyte_secrets_utils import filter_secrets
 from dataclasses_jsonschema import JsonSchemaMixin
 
 
@@ -46,9 +52,10 @@ class SimpleRetriever(Retriever, HttpStream, JsonSchemaMixin):
 
     requester: Requester
     record_selector: HttpSelector
+    config: Config
     options: InitVar[Mapping[str, Any]]
     name: str
-    _name: str = field(init=False, repr=False, default="")
+    _name: Union[InterpolatedString, str] = field(init=False, repr=False, default="")
     primary_key: Optional[Union[str, List[str], List[List[str]]]]
     _primary_key: str = field(init=False, repr=False, default="")
     paginator: Optional[Paginator] = None
@@ -59,13 +66,15 @@ class SimpleRetriever(Retriever, HttpStream, JsonSchemaMixin):
         HttpStream.__init__(self, self.requester.get_authenticator())
         self._last_response = None
         self._last_records = None
+        self._options = options
+        self.name = InterpolatedString(self._name, options=options)
 
     @property
     def name(self) -> str:
         """
         :return: Stream name
         """
-        return self._name
+        return self._name.eval(self.config)
 
     @name.setter
     def name(self, value: str) -> None:
@@ -310,7 +319,10 @@ class SimpleRetriever(Retriever, HttpStream, JsonSchemaMixin):
         # else -> delegate to record selector
         response_status = self.requester.interpret_response_status(response)
         if response_status.action == ResponseAction.FAIL:
-            error_message = response_status.error_message or f"Request {response.request} failed with response {response}"
+            error_message = (
+                response_status.error_message
+                or f"Request to {response.request.url} failed with status code {response.status_code} and error message {HttpStream.parse_response_error_message(response)}"
+            )
             raise ReadException(error_message)
         elif response_status.action == ResponseAction.IGNORE:
             self.logger.info(f"Ignoring response for failed request with error message {HttpStream.parse_response_error_message(response)}")
@@ -347,20 +359,27 @@ class SimpleRetriever(Retriever, HttpStream, JsonSchemaMixin):
     def read_records(
         self,
         sync_mode: SyncMode,
-        cursor_field: List[str] = None,
+        cursor_field: Optional[List[str]] = None,
         stream_slice: Optional[StreamSlice] = None,
         stream_state: Optional[StreamState] = None,
-    ) -> Iterable[Mapping[str, Any]]:
+    ) -> Iterable[StreamData]:
         # Warning: use self.state instead of the stream_state passed as argument!
         stream_slice = stream_slice or {}  # None-check
         self.paginator.reset()
-        records_generator = HttpStream.read_records(self, sync_mode, cursor_field, stream_slice, self.state)
-        for r in records_generator:
-            self.stream_slicer.update_cursor(stream_slice, last_record=r)
-            yield r
+        records_generator = self._read_pages(
+            self.parse_records_and_emit_request_and_responses,
+            stream_slice,
+            stream_state,
+        )
+        for record in records_generator:
+            # Only record messages should be parsed to update the cursor which is indicated by the Mapping type
+            if isinstance(record, Mapping):
+                self.stream_slicer.update_cursor(stream_slice, last_record=record)
+            yield record
         else:
             last_record = self._last_records[-1] if self._last_records else None
-            self.stream_slicer.update_cursor(stream_slice, last_record=last_record)
+            if last_record and isinstance(last_record, Mapping):
+                self.stream_slicer.update_cursor(stream_slice, last_record=last_record)
             yield from []
 
     def stream_slices(
@@ -385,3 +404,24 @@ class SimpleRetriever(Retriever, HttpStream, JsonSchemaMixin):
     def state(self, value: StreamState):
         """State setter, accept state serialized by state getter."""
         self.stream_slicer.update_cursor(value)
+
+    def parse_records_and_emit_request_and_responses(self, request, response, stream_slice, stream_state) -> Iterable[StreamData]:
+        # Only emit requests and responses when running in debug mode
+        if self.logger.isEnabledFor(logging.DEBUG):
+            yield self._create_trace_message_from_request(request)
+            yield self._create_trace_message_from_response(response)
+        # Not great to need to call _read_pages which is a private method
+        # A better approach would be to extract the HTTP client from the HttpStream and call it directly from the HttpRequester
+        yield from self.parse_response(response, stream_slice=stream_slice, stream_state=stream_state)
+
+    def _create_trace_message_from_request(self, request: requests.PreparedRequest):
+        # FIXME: this should return some sort of trace message
+        request_dict = {"url": request.url, "http_method": request.method, "headers": dict(request.headers), "body": request.body}
+        log_message = filter_secrets(f"request:{json.dumps(request_dict)}")
+        return AirbyteMessage(type=MessageType.LOG, log=AirbyteLogMessage(level=Level.INFO, message=log_message))
+
+    def _create_trace_message_from_response(self, response: requests.Response):
+        # FIXME: this should return some sort of trace message
+        response_dict = {"body": response.text, "headers": dict(response.headers), "status_code": response.status_code}
+        log_message = filter_secrets(f"response:{json.dumps(response_dict)}")
+        return AirbyteMessage(type=MessageType.LOG, log=AirbyteLogMessage(level=Level.INFO, message=log_message))
