@@ -15,7 +15,7 @@ from airbyte_cdk.sources.declarative.extractors.record_filter import RecordFilte
 from airbyte_cdk.sources.declarative.extractors.record_selector import RecordSelector
 from airbyte_cdk.sources.declarative.interpolation import InterpolatedString
 from airbyte_cdk.sources.declarative.parsers.factory import DeclarativeComponentFactory
-from airbyte_cdk.sources.declarative.parsers.yaml_parser import YamlParser
+from airbyte_cdk.sources.declarative.parsers.manifest_reference_resolver import ManifestReferenceResolver
 from airbyte_cdk.sources.declarative.requesters.error_handlers import BackoffStrategy
 from airbyte_cdk.sources.declarative.requesters.error_handlers.backoff_strategies import (
     ConstantBackoffStrategy,
@@ -40,12 +40,13 @@ from airbyte_cdk.sources.declarative.stream_slicers.datetime_stream_slicer impor
 from airbyte_cdk.sources.declarative.stream_slicers.list_stream_slicer import ListStreamSlicer
 from airbyte_cdk.sources.declarative.transformations import AddFields, RemoveFields
 from airbyte_cdk.sources.declarative.transformations.add_fields import AddedFieldDefinition
+from airbyte_cdk.sources.declarative.yaml_declarative_source import YamlDeclarativeSource
 from dateutil.relativedelta import relativedelta
 from jsonschema import ValidationError
 
 factory = DeclarativeComponentFactory()
 
-parser = YamlParser()
+resolver = ManifestReferenceResolver()
 
 input_config = {"apikey": "verysecrettoken", "repos": ["airbyte", "airbyte-cloud"]}
 
@@ -64,7 +65,7 @@ def test_factory():
       request_body_json:
         body_offset: "{{ next_page_token['offset'] }}"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["request_options"], input_config, False)
 
@@ -89,7 +90,7 @@ def test_interpolate_config():
         body_field: "yoyoyo"
         interpolated_body_field: "{{ config['apikey'] }}"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["authenticator"], input_config, False)
 
@@ -111,7 +112,7 @@ def test_list_based_stream_slicer_with_values_refd():
       slice_values: "*ref(repositories)"
       cursor_field: repository
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["stream_slicer"], input_config, False)
 
@@ -129,7 +130,7 @@ def test_list_based_stream_slicer_with_values_defined_in_config():
         inject_into: header
         field_name: repository
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["stream_slicer"], input_config, False)
 
@@ -181,7 +182,7 @@ def test_create_substream_slicer():
           parent_key: someid
           stream_slice_field: word_id
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     stream_slicer = factory.create_component(config["stream_slicer"], input_config)()
     parent_stream_configs = stream_slicer.parent_stream_configs
@@ -216,7 +217,7 @@ def test_create_cartesian_stream_slicer():
         - "*ref(stream_slicer_A)"
         - "*ref(stream_slicer_B)"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["stream_slicer"], input_config, False)
 
@@ -248,7 +249,7 @@ def test_datetime_stream_slicer():
           field_name: created[gte]
     """
 
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["stream_slicer"], input_config, False)
 
@@ -362,7 +363,7 @@ spec:
         description: Test API Key
         order: 0
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["list_stream"], input_config, False)
 
@@ -429,7 +430,7 @@ def test_create_record_selector(test_name, record_selector, expected_runtime_sel
         $ref: "*ref(extractor)"
         field_pointer: ["{record_selector}"]
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["selector"], input_config, False)
 
@@ -476,7 +477,7 @@ def test_create_record_selector(test_name, record_selector, expected_runtime_sel
     ],
 )
 def test_options_propagation(test_name, content, expected_field_pointer_value):
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     selector = factory.create_component(config["selector"], input_config, True)()
     assert selector.extractor.field_pointer[0].eval(input_config) == expected_field_pointer_value
@@ -546,7 +547,7 @@ def test_create_requester(test_name, error_handler):
         header: header_value
     {error_handler}
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["requester"], input_config, False)
 
@@ -576,7 +577,7 @@ def test_create_composite_error_handler():
                 - http_codes: [ 403 ]
                   action: RETRY
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["error_handler"], input_config, False)
 
@@ -625,7 +626,7 @@ def test_config_with_defaults():
     streams:
       - "*ref(lists_stream)"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["lists_stream"], input_config, False)
 
@@ -662,7 +663,7 @@ def test_create_default_paginator():
           page_size: 50
           cursor_value: "{{ response._metadata.next }}"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
     factory.create_component(config["paginator"], input_config, False)
 
@@ -701,7 +702,7 @@ class TestCreateTransformations:
             $options:
                 {self.base_options}
         """
-        config = parser.parse(content)
+        config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
         factory.create_component(config["the_stream"], input_config, False)
 
@@ -721,7 +722,7 @@ class TestCreateTransformations:
                         - ["path", "to", "field1"]
                         - ["path2"]
         """
-        config = parser.parse(content)
+        config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
         factory.create_component(config["the_stream"], input_config, False)
 
@@ -742,7 +743,7 @@ class TestCreateTransformations:
                         - path: ["field1"]
                           value: "static_value"
         """
-        config = parser.parse(content)
+        config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
 
         factory.create_component(config["the_stream"], input_config, False)
 
@@ -774,7 +775,7 @@ def test_validation_wrong_input_type():
         $ref: "*ref(extractor)"
         field_pointer: 408
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     with pytest.raises(ValidationError):
         factory.create_component(config["selector"], input_config, False)
 
@@ -797,7 +798,7 @@ def test_validation_type_missing_required_fields():
         field_name: created[gte]
     """
 
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     with pytest.raises(ValidationError):
         factory.create_component(config["stream_slicer"], input_config, False)
 
@@ -817,7 +818,7 @@ def test_validation_wrong_interface_type():
         type: "MinMaxDatetime"
         datetime: "{{ response._metadata.next }}"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     with pytest.raises(ValidationError):
         factory.create_component(config["paginator"], input_config, False)
 
@@ -833,7 +834,7 @@ def test_validation_create_composite_error_handler():
             - response_filters:
                 - http_codes: [ 403 ]
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     with pytest.raises(ValidationError):
         factory.create_component(config["error_handler"], input_config, False)
 
@@ -858,7 +859,7 @@ def test_validation_wrong_object_type():
           type: "MinMaxDatetime"
           datetime: "{{ response._metadata.next }}"
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     factory.create_component(config["paginator"], input_config, False)
 
 
@@ -872,7 +873,7 @@ def test_validate_types_nested_in_list():
         - type: DpathExtractor
           field_pointer: ["result"]
     """
-    config = parser.parse(content)
+    config = resolver.preprocess_manifest(YamlDeclarativeSource._parse(content), {}, "")
     factory.create_component(config["error_handler"], input_config, False)
 
 
