@@ -470,9 +470,9 @@ def test_generate_schema():
     schema = json.loads(schema_str)
 
     assert "version" in schema["required"]
-    assert "checker" in schema["required"]
+    assert "check" in schema["required"]
     assert "streams" in schema["required"]
-    assert schema["properties"]["checker"]["$ref"] == "#/definitions/CheckStream"
+    assert schema["properties"]["check"]["$ref"] == "#/definitions/CheckStream"
     assert schema["properties"]["streams"]["items"]["$ref"] == "#/definitions/DeclarativeStream"
 
     check_stream = schema["definitions"]["CheckStream"]
@@ -547,7 +547,7 @@ def test_generate_schema():
     assert default_error_handler["properties"]["backoff_strategies"]["type"] == "array"
 
     default_paginator = schema["definitions"]["DefaultPaginator"]["allOf"][1]
-    assert {"page_token_option", "pagination_strategy", "config", "url_base"}.issubset(default_paginator["required"])
+    assert {"pagination_strategy", "config", "url_base"}.issubset(default_paginator["required"])
     assert default_paginator["properties"]["page_size_option"]["$ref"] == "#/definitions/RequestOption"
     assert default_paginator["properties"]["page_token_option"]["$ref"] == "#/definitions/RequestOption"
     assert {"$ref": "#/definitions/CursorPaginationStrategy"} in default_paginator["properties"]["pagination_strategy"]["anyOf"]
